#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_TRUNC_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_TRUNC_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/trunc.hpp>

#endif
